from django.db import models
from gst_field.modelfields import GSTField
from django.contrib.auth.models import User
from random import randint
from django.core.validators import MaxValueValidator, MinValueValidator

# Create your models here.
class UserData(models.Model):
    user = models.OneToOneField(User, on_delete=models.CASCADE, unique=True,  default=101)
    name = models.CharField(max_length=100)
    email = models.EmailField(max_length=254)
    password = models.CharField(max_length=100)
    mobile = models.CharField(max_length=15)
    # dob = models.CharField(max_length=15)
    gst = GSTField(default='abc12345')
    comp_name = models.CharField(max_length=100, default='blank')
    address = models.TextField(max_length=200, default='blank')
    state = models.CharField(max_length=100, default='blank')
    pincode = models.CharField(max_length=8, default=12346)
    rating = models.IntegerField(default=0)
    otp = models.IntegerField(null=True, blank=True)
    activation_key = models.CharField(max_length=150, blank=True, null=True)
    priority = models.PositiveIntegerField(null=True, validators=[MaxValueValidator(10), MinValueValidator(1)])

    def __str__(self):
        return str(self.id) + "-" + str(self.name)


class SellerData(models.Model):
    user = models.OneToOneField(User, on_delete=models.CASCADE, unique=True, default=100)
    name = models.CharField(max_length=100)
    email = models.EmailField(max_length=254)
    password = models.CharField(max_length=100)
    mobile = models.CharField(max_length=15)
    gst = GSTField()
    comp_name = models.CharField(max_length=100)
    address = models.TextField(max_length=200)
    state = models.CharField(max_length=100)
    pincode = models.CharField(max_length=8)
    rating = models.IntegerField(default=0)
    otp = models.IntegerField(null=True, blank=True)
    activation_key = models.CharField(max_length=150, blank=True, null=True)
    priority = models.PositiveIntegerField(null=True, validators=[MaxValueValidator(10), MinValueValidator(1)])

    def __str__(self):
        return str(self.id) + "-" + str(self.name)


class KisanData(models.Model):
    user = models.OneToOneField(User, on_delete=models.CASCADE, unique=True, default=102)
    name = models.CharField(max_length=100)
    email = models.EmailField(max_length=254, null=True)
    password = models.CharField(max_length=100)
    mobile = models.CharField(max_length=12, unique=True)
    address = models.TextField(max_length=200)
    city = models.CharField(max_length=100)
    state = models.CharField(max_length=100)
    pincode = models.CharField(max_length=8)
    rating = models.IntegerField(default=0)
    otp = models.IntegerField(null=True, blank=True)
    activation_key = models.CharField(max_length=150, blank=True, null=True)
    priority = models.PositiveIntegerField(null=True, validators=[MaxValueValidator(10), MinValueValidator(1)])

    def __str__(self):
        return str(self.id) + "-" + str(self.name)

import random
from django.utils import timezone
import datetime

def generate_pk():
    number = random.randint(1000, 9999)
    return 'AA{}{}'.format(timezone.now().strftime('%y%m%d'), number)


class Manufacturer(models.Model):
    user = models.OneToOneField(User, on_delete=models.CASCADE, unique=True, default=102)
    # mfr_id = models.CharField(default=generate_pk, primary_key=True, max_length=255, unique=True)
    mfr_id = models.CharField(max_length=255, null=True, default=None)
    brand_name = models.CharField(max_length=100)
    mfr_cat = models.CharField(max_length=30)
    contact_name = models.CharField(max_length=100)
    email = models.EmailField(max_length=254, null=False, default=None)
    mobile = models.CharField(max_length=12, unique=True)
    password = models.CharField(max_length=100)
    address = models.TextField(max_length=200)
    city = models.CharField(max_length=50)
    state = models.CharField(max_length=50)
    pincode = models.CharField(max_length=8)
    rating = models.IntegerField(default=0,validators=[MaxValueValidator(5), MinValueValidator(0)])
    # rating = models.IntegerField(default=0)
    otp = models.IntegerField(null=True, blank=True)
    activation_key = models.CharField(max_length=150, blank=True, null=True)
    priority = models.PositiveIntegerField(null=True, validators=[MaxValueValidator(10), MinValueValidator(0)])

    def save(self, *args, **kwargs):
        if not self.mfr_id:
            # using julian date instead of normal date
            dt = datetime.datetime.now().timetuple()
            prefix = 'SP{}{}{}{}'.format(self.mfr_cat[:5], dt.tm_year * 1000 + dt.tm_yday, self.brand_name[:5], randint(10, 99))
            # prefix = 'AA{}'.format(timezone.now().strftime('%y%m%d'))
            prev_instances = self.__class__.objects.filter(mfr_id__contains=prefix)
            if prev_instances.exists():
                last_instance_id = prev_instances.last().mfr_id[-2:]
                self.mfr_id = prefix + '{0:02d}'.format(int(last_instance_id) + 1)
            else:
                self.mfr_id = prefix + '{0:02d}'.format(1)
        super(Manufacturer, self).save(*args, **kwargs)


    def __str__(self):
        return str(self.id) + "-" + str(self.brand_name)


class MyData(models.Model):
    name = models.CharField(max_length=100)
    email = models.EmailField(max_length=254, null=True)
